@@ -163,9 +163,8 @@ def keyscan():
         led.test_led(R_val = 40, G_val = 0, B_val = 0)
         led.test_led(R_val = 0, G_val = 70, B_val =0)
         led.test_led(R_val = 0, G_val = 0, B_val = 90)
-
+    
     time.sleep(0.1) # after start, set green light on and red off
-
     return
 
     # another press will stop the program
@@ -173,6 +172,8 @@ def keyscan():
     GPIO.add_event_detect(BtnPin, GPIO.BOTH,
                 callback= stop_vehicle,
                 bouncetime=200) # TypeError: xxx() takes 0 positional arguments but 1 was given
+
+    return
             
 def setup():
 
@@ -195,10 +196,6 @@ def setup():
     GPIO.setup(TRIG, GPIO.OUT)
     GPIO.setup(ECHO, GPIO.IN)
 
-    # lcd. now can only control backlight, research later
-    lcd = LiquidCrystal_I2C()
-    lcd.noBacklight()
-
     if ENABLE_BUTTON:
         GPIO.setup(BtnPin, GPIO.IN, pull_up_down=GPIO.PUD_UP)    # Set BtnPin's mode is input, and pull up to high level(3.3V)
     else:
