@@ -19,18 +19,24 @@ About binding keys to functions, refer to:
 https://tkinterexamples.com/events/keyboard/
 '''
 
+LCD_DRIVER_I = False # we provide two vers of lcd driver
+
 if __package__:
     from . import led, acc, servo, joystick
     from . import passive_buzzer as pbz
     from . import PCF8591 as adc
     from . import ds18b20 as temperature
     from .setting_frame import SettingFrame
+    from . import LCD1602 as lcd
+    from .liquidcrystal_i2c import LiquidCrystal_I2C
 else:
     import led, acc, servo, joystick
     import passive_buzzer as pbz
     import PCF8591 as adc
     import ds18b20 as temperature
     from setting_frame import SettingFrame
+    import LCD1602 as lcd
+    from liquidcrystal_i2c import LiquidCrystal_I2C
 # import sys
 # sys.path.insert(0, './vehicle')
 # import vehicle.Adafruit_PWM_Servo_Driver as servo_drv
@@ -48,6 +54,7 @@ TREEVIEW_ROW_HEIGHT = 21
 
 TEST_LED = '1'
 TEST_PASSIVE_BUZZER = '3'
+TEST_LCD = '11'
 TEST_SERVO = '4'
 TEST_RA = '8'
 TEST_JOYSTICK = '2'
@@ -72,7 +79,7 @@ class MainGui(ttk.Frame):
         # servo.setup()  # called inside acc.setup()
         joystick.RUNNING = False
         adc.RUNNING = False
-        acc.RUNNINGwadw = False
+        acc.RUNNING = False
         acc.setup()
         
         self.distance_F = 1000
@@ -647,6 +654,7 @@ servo channels:
         tv.insert('', END, TEST_LASER, values = ('Laser', '17', 'Laser'))       
         tv.insert('', END, TEST_W1, values = ('Temperature', '1-Wire', 'ds18b20'))
         tv.insert('', END, TEST_PASSIVE_BUZZER, values = ('Passive Buzzer', '17', '声音'))
+        tv.insert('', END, TEST_LCD, values = ('LCD', 'I2C 0x27', 'LCD 1602+PCF8674'))
         tv.insert('', END, TEST_SERVO, values = ('Servos', 'I2C 0x40 0~7', '舵机'))
         tv.insert('', END, TEST_RA, values = ('Robotic Arm', 'I2C 0x40 4~7', '机械臂'))
         tv.insert('', END, TEST_JOYSTICK, values = ('Joystick', 'I2C 0x48 A0A1A2', 'Joystick Controller'))
@@ -677,6 +685,34 @@ servo channels:
                 self.test_pbz = Thread(target = pbz.loop)
                 self.test_pbz.setDaemon(True)
                 self.test_pbz.start()
+        
+        elif item == TEST_LCD: 
+            
+            if not LCD_DRIVER_I:
+
+                lcd2 = LiquidCrystal_I2C()
+                lcd2.noBacklight()
+
+                cols = 16
+                l1 = 'liquidcrystal_i2c'.center(cols)
+                l2 = '@hangzhou'.rjust(cols)
+                for i in range(cols):
+
+                    l1 = l1[-1] + l1[:-1]
+                    l2 = l2[-1] + l2[:-1]
+
+                    lcd2.printline(0, l1)
+                    lcd2.printline(1, l2)
+                    time.sleep(1)
+                
+                time.sleep(1)
+                lcd2.noBacklight()
+                lcd2.clear()
+
+            else:
+                lcd.setup()
+                lcd.test_lcd()
+                lcd.lightoff()
 
         elif item == TEST_SERVO: 
             self.test_servo = Thread(target = servo.test_servo)
